@@ -33,7 +33,7 @@ class TestSSH:
                 str(dbsession.bind.engine.url)
                 == "postgresql+psycopg://myuser@0.0.0.0:12345/mydatabase"
             )
-            assert dbdatabase.base == TZBase
+            assert dbdatabase._base == TZBase
 
         with Database(
             ssh_host="mysshhost", ssh_port=25, table_base=TZBase, **params
@@ -43,7 +43,7 @@ class TestSSH:
                 str(dbsession.bind.engine.url)
                 == "postgresql+psycopg://myuser@0.0.0.0:12345/mydatabase"
             )
-            assert dbdatabase.base == TZBase
+            assert dbdatabase._base == TZBase
 
         with Database(ssh_host="mysshhost", **self.params_pg) as dbdatabase:
             dbsession = dbdatabase.get_session()
@@ -51,7 +51,7 @@ class TestSSH:
                 str(dbsession.bind.engine.url)
                 == "postgresql+psycopg://myuser:***@0.0.0.0:12345/mydatabase"
             )
-            assert dbdatabase.base == NoTZBase
+            assert dbdatabase._base == NoTZBase
 
         with Database(
             ssh_host="mysshhost", ssh_port=25, **params
@@ -61,4 +61,4 @@ class TestSSH:
                 str(dbsession.bind.engine.url)
                 == "postgresql+psycopg://myuser@0.0.0.0:12345/mydatabase"
             )
-            assert dbdatabase.base == NoTZBase
+            assert dbdatabase._base == NoTZBase
